Index — FastMBAR 1.0-rc documentation

Skip to main content
`Ctrl`+`K`

#

# Index

_ | C | D | F | L

## _

__init__() (FastMBAR.FastMBAR method)

## C

calculate_free_energies_of_perturbed_states() (FastMBAR.FastMBAR method)

## D

DeltaF (FastMBAR.FastMBAR property) | DeltaF_std (FastMBAR.FastMBAR property)

## F

F (FastMBAR.FastMBAR property) F_cov (FastMBAR.FastMBAR property) | F_std (FastMBAR.FastMBAR property) FastMBAR (class in FastMBAR)

## L

log_prob_mix (FastMBAR.FastMBAR property)